Struct sn_testnet::Testnet
source · pub struct Testnet {
pub node_bin_path: PathBuf,
pub node_launch_interval: u64,
pub nodes_dir_path: PathBuf,
pub flamegraph_mode: bool,
pub node_count: usize,
pub launcher: Box<dyn NodeLauncher>,
pub rpc_client: Box<dyn RpcClient>,
}Fields
node_bin_path: PathBufnode_launch_interval: u64nodes_dir_path: PathBufflamegraph_mode: boolnode_count: usizelauncher: Box<dyn NodeLauncher>rpc_client: Box<dyn RpcClient>Implementations
sourceimpl Testnet
impl Testnet
sourcepub fn new(
node_bin_path: PathBuf,
node_launch_interval: u64,
nodes_dir_path: PathBuf,
flamegraph_mode: bool,
launcher: Box<dyn NodeLauncher>,
rpc_client: Box<dyn RpcClient>
) -> Result<Self>
pub fn new( node_bin_path: PathBuf, node_launch_interval: u64, nodes_dir_path: PathBuf, flamegraph_mode: bool, launcher: Box<dyn NodeLauncher>, rpc_client: Box<dyn RpcClient> ) -> Result<Self>
Create a new Testnet instance.
The node_data_dir path will be inspected to see if it already exists, and if so, to
obtain the number of nodes. This is used for having nodes join an existing network.
sourcepub fn configure() -> TestnetBuilder
pub fn configure() -> TestnetBuilder
Use this function to create a Testnet with a fluent interface.
sourcepub async fn launch_genesis(&self, node_args: Vec<String>) -> Result<String>
pub async fn launch_genesis(&self, node_args: Vec<String>) -> Result<String>
Launches a genesis node at 127.0.0.1:11101.
The RPC service is launched along with the node, on port 12001.
Returns the MultiAdrr of the genesis node, including the peer ID.
Arguments
node_args- Additional arguments to pass to the node process, e.g., –json-log-output.
Errors
Returns an error if:
- The node data directory is already populated with previous node root directories
- The node process fails
sourcepub fn launch_nodes(
&mut self,
number_of_nodes: usize,
node_args: &[String]
) -> Result<()>
pub fn launch_nodes( &mut self, number_of_nodes: usize, node_args: &[String] ) -> Result<()>
Launches a number of new nodes, either for a new network or an existing network.
Arguments
number_of_nodes- The number of nodes to launch.node_args- Additional arguments to pass to the node process, e.g., –json-logs.
Errors
Returns an error if:
- The node data directories cannot be created
- The node process fails